==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/scenekit/SCNSceneRendererDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.scenekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.glkit.*;
import org.robovm.apple.spritekit.*;
import org.robovm.apple.opengles.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/SCNSceneRendererDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    /**
     * @since Available in iOS 8.0 and later.
     */
    @Method(selector = "renderer:updateAtTime:")
    void update(SCNSceneRenderer aRenderer, double time);
    /**
     * @since Available in iOS 8.0 and later.
     */
    @Method(selector = "renderer:didApplyAnimationsAtTime:")
    void didApplyAnimations(SCNSceneRenderer aRenderer, double time);
    /**
     * @since Available in iOS 8.0 and later.
     */
    @Method(selector = "renderer:didSimulatePhysicsAtTime:")
    void didSimulatePhysics(SCNSceneRenderer aRenderer, double time);
    @Method(selector = "renderer:willRenderScene:atTime:")
    void willRenderScene(SCNSceneRenderer aRenderer, SCNScene scene, double time);
    @Method(selector = "renderer:didRenderScene:atTime:")
    void didRenderScene(SCNSceneRenderer aRenderer, SCNScene scene, double time);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/scenekit/SCNSceneRendererDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.scenekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.glkit.*;
import org.robovm.apple.spritekit.*;
import org.robovm.apple.opengles.*;
import org.robovm.apple.metal.*;
import org.robovm.apple.avfoundation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/SCNSceneRendererDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "renderer:updateAtTime:")
    void update(SCNSceneRenderer renderer, double time);
    @Method(selector = "renderer:didApplyAnimationsAtTime:")
    void didApplyAnimations(SCNSceneRenderer renderer, double time);
    @Method(selector = "renderer:didSimulatePhysicsAtTime:")
    void didSimulatePhysics(SCNSceneRenderer renderer, double time);
    /**
     * @since Available in iOS 11.0 and later.
     */
    @Method(selector = "renderer:didApplyConstraintsAtTime:")
    void didApplyConstraints(SCNSceneRenderer renderer, double time);
    @Method(selector = "renderer:willRenderScene:atTime:")
    void willRenderScene(SCNSceneRenderer renderer, SCNScene scene, double time);
    @Method(selector = "renderer:didRenderScene:atTime:")
    void didRenderScene(SCNSceneRenderer renderer, SCNScene scene, double time);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}
